==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/EwidencjaDpsZgon.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.StatusEwidencjiZgonu;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class EwidencjaDpsZgon extends GenericDPSObject {
    /**
     * EWIDENCJA_DPS_ZGON.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * EWIDENCJA_DPS_ZGON.USC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long uscId;

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_ZGONU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long miejsceZgonuId;

    /**
     * EWIDENCJA_DPS_ZGON.ODPOWIEDZIALNY_ZA_POGRZEB_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long odpowiedzialnyZaPogrzebId;

    /**
     * EWIDENCJA_DPS_ZGON.GODZINA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer godzina;

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_POCHOWKU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String miejscePochowku;

    /**
     * EWIDENCJA_DPS_ZGON.NR_AKT_ZGON
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nrAktZgon;

    /**
     * EWIDENCJA_DPS_ZGON.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusEwidencjiZgonu status;

    /**
     * EWIDENCJA_DPS_ZGON.UWAGI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String uwagi;

    /**
     * EWIDENCJA_DPS_ZGON.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return EWIDENCJA_DPS_ZGON.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * EWIDENCJA_DPS_ZGON.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.USC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getUscId() {
        return uscId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.USC_ID
     *
     * @param uscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUscId(Long uscId) {
        this.uscId = uscId;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.MIEJSCE_ZGONU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getMiejsceZgonuId() {
        return miejsceZgonuId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_ZGONU_ID
     *
     * @param miejsceZgonuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiejsceZgonuId(Long miejsceZgonuId) {
        this.miejsceZgonuId = miejsceZgonuId;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.ODPOWIEDZIALNY_ZA_POGRZEB_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOdpowiedzialnyZaPogrzebId() {
        return odpowiedzialnyZaPogrzebId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.ODPOWIEDZIALNY_ZA_POGRZEB_ID
     *
     * @param odpowiedzialnyZaPogrzebId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdpowiedzialnyZaPogrzebId(Long odpowiedzialnyZaPogrzebId) {
        this.odpowiedzialnyZaPogrzebId = odpowiedzialnyZaPogrzebId;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.GODZINA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getGodzina() {
        return godzina;
    }

    /**
     * EWIDENCJA_DPS_ZGON.GODZINA
     *
     * @param godzina
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGodzina(Integer godzina) {
        this.godzina = godzina;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.MIEJSCE_POCHOWKU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getMiejscePochowku() {
        return miejscePochowku;
    }

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_POCHOWKU
     *
     * @param miejscePochowku
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiejscePochowku(String miejscePochowku) {
        this.miejscePochowku = miejscePochowku == null ? null : miejscePochowku.trim();
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.NR_AKT_ZGON
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNrAktZgon() {
        return nrAktZgon;
    }

    /**
     * EWIDENCJA_DPS_ZGON.NR_AKT_ZGON
     *
     * @param nrAktZgon
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrAktZgon(String nrAktZgon) {
        this.nrAktZgon = nrAktZgon == null ? null : nrAktZgon.trim();
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusEwidencjiZgonu getStatus() {
        return status;
    }

    /**
     * EWIDENCJA_DPS_ZGON.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusEwidencjiZgonu status) {
        this.status = status;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.UWAGI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * EWIDENCJA_DPS_ZGON.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        EwidencjaDpsZgon other = (EwidencjaDpsZgon) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getUscId() == null ? other.getUscId() == null : this.getUscId().equals(other.getUscId()))
            && (this.getMiejsceZgonuId() == null ? other.getMiejsceZgonuId() == null : this.getMiejsceZgonuId().equals(other.getMiejsceZgonuId()))
            && (this.getOdpowiedzialnyZaPogrzebId() == null ? other.getOdpowiedzialnyZaPogrzebId() == null : this.getOdpowiedzialnyZaPogrzebId().equals(other.getOdpowiedzialnyZaPogrzebId()))
            && (this.getGodzina() == null ? other.getGodzina() == null : this.getGodzina().equals(other.getGodzina()))
            && (this.getMiejscePochowku() == null ? other.getMiejscePochowku() == null : this.getMiejscePochowku().equals(other.getMiejscePochowku()))
            && (this.getNrAktZgon() == null ? other.getNrAktZgon() == null : this.getNrAktZgon().equals(other.getNrAktZgon()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getUscId() == null) ? 0 : getUscId().hashCode());
        result = prime * result + ((getMiejsceZgonuId() == null) ? 0 : getMiejsceZgonuId().hashCode());
        result = prime * result + ((getOdpowiedzialnyZaPogrzebId() == null) ? 0 : getOdpowiedzialnyZaPogrzebId().hashCode());
        result = prime * result + ((getGodzina() == null) ? 0 : getGodzina().hashCode());
        result = prime * result + ((getMiejscePochowku() == null) ? 0 : getMiejscePochowku().hashCode());
        result = prime * result + ((getNrAktZgon() == null) ? 0 : getNrAktZgon().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", uscId=").append(uscId);
        sb.append(", miejsceZgonuId=").append(miejsceZgonuId);
        sb.append(", odpowiedzialnyZaPogrzebId=").append(odpowiedzialnyZaPogrzebId);
        sb.append(", godzina=").append(godzina);
        sb.append(", miejscePochowku=").append(miejscePochowku);
        sb.append(", nrAktZgon=").append(nrAktZgon);
        sb.append(", status=").append(status);
        sb.append(", uwagi=").append(uwagi);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/EwidencjaDpsZgon.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.StatusEwidencjiZgonu;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class EwidencjaDpsZgon extends GenericDPSObject {
    /**
     * EWIDENCJA_DPS_ZGON.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * EWIDENCJA_DPS_ZGON.USC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long uscId;

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_ZGONU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long miejsceZgonuId;

    /**
     * EWIDENCJA_DPS_ZGON.ODPOWIEDZIALNY_ZA_POGRZEB_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long odpowiedzialnyZaPogrzebId;

    /**
     * EWIDENCJA_DPS_ZGON.GODZINA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer godzina;

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_POCHOWKU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String miejscePochowku;

    /**
     * EWIDENCJA_DPS_ZGON.NR_AKT_ZGON
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nrAktZgon;

    /**
     * EWIDENCJA_DPS_ZGON.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusEwidencjiZgonu status;

    /**
     * EWIDENCJA_DPS_ZGON.UWAGI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String uwagi;

    /**
     * EWIDENCJA_DPS_ZGON.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return EWIDENCJA_DPS_ZGON.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * EWIDENCJA_DPS_ZGON.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.USC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getUscId() {
        return uscId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.USC_ID
     *
     * @param uscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUscId(Long uscId) {
        this.uscId = uscId;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.MIEJSCE_ZGONU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getMiejsceZgonuId() {
        return miejsceZgonuId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_ZGONU_ID
     *
     * @param miejsceZgonuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiejsceZgonuId(Long miejsceZgonuId) {
        this.miejsceZgonuId = miejsceZgonuId;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.ODPOWIEDZIALNY_ZA_POGRZEB_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOdpowiedzialnyZaPogrzebId() {
        return odpowiedzialnyZaPogrzebId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.ODPOWIEDZIALNY_ZA_POGRZEB_ID
     *
     * @param odpowiedzialnyZaPogrzebId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdpowiedzialnyZaPogrzebId(Long odpowiedzialnyZaPogrzebId) {
        this.odpowiedzialnyZaPogrzebId = odpowiedzialnyZaPogrzebId;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.GODZINA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getGodzina() {
        return godzina;
    }

    /**
     * EWIDENCJA_DPS_ZGON.GODZINA
     *
     * @param godzina
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGodzina(Integer godzina) {
        this.godzina = godzina;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.MIEJSCE_POCHOWKU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getMiejscePochowku() {
        return miejscePochowku;
    }

    /**
     * EWIDENCJA_DPS_ZGON.MIEJSCE_POCHOWKU
     *
     * @param miejscePochowku
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiejscePochowku(String miejscePochowku) {
        this.miejscePochowku = miejscePochowku == null ? null : miejscePochowku.trim();
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.NR_AKT_ZGON
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNrAktZgon() {
        return nrAktZgon;
    }

    /**
     * EWIDENCJA_DPS_ZGON.NR_AKT_ZGON
     *
     * @param nrAktZgon
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrAktZgon(String nrAktZgon) {
        this.nrAktZgon = nrAktZgon == null ? null : nrAktZgon.trim();
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusEwidencjiZgonu getStatus() {
        return status;
    }

    /**
     * EWIDENCJA_DPS_ZGON.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusEwidencjiZgonu status) {
        this.status = status;
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.UWAGI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * EWIDENCJA_DPS_ZGON.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @return EWIDENCJA_DPS_ZGON.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * EWIDENCJA_DPS_ZGON.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        EwidencjaDpsZgon other = (EwidencjaDpsZgon) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getUscId() == null ? other.getUscId() == null : this.getUscId().equals(other.getUscId()))
            && (this.getMiejsceZgonuId() == null ? other.getMiejsceZgonuId() == null : this.getMiejsceZgonuId().equals(other.getMiejsceZgonuId()))
            && (this.getOdpowiedzialnyZaPogrzebId() == null ? other.getOdpowiedzialnyZaPogrzebId() == null : this.getOdpowiedzialnyZaPogrzebId().equals(other.getOdpowiedzialnyZaPogrzebId()))
            && (this.getGodzina() == null ? other.getGodzina() == null : this.getGodzina().equals(other.getGodzina()))
            && (this.getMiejscePochowku() == null ? other.getMiejscePochowku() == null : this.getMiejscePochowku().equals(other.getMiejscePochowku()))
            && (this.getNrAktZgon() == null ? other.getNrAktZgon() == null : this.getNrAktZgon().equals(other.getNrAktZgon()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getUscId() == null) ? 0 : getUscId().hashCode());
        result = prime * result + ((getMiejsceZgonuId() == null) ? 0 : getMiejsceZgonuId().hashCode());
        result = prime * result + ((getOdpowiedzialnyZaPogrzebId() == null) ? 0 : getOdpowiedzialnyZaPogrzebId().hashCode());
        result = prime * result + ((getGodzina() == null) ? 0 : getGodzina().hashCode());
        result = prime * result + ((getMiejscePochowku() == null) ? 0 : getMiejscePochowku().hashCode());
        result = prime * result + ((getNrAktZgon() == null) ? 0 : getNrAktZgon().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", uscId=").append(uscId);
        sb.append(", miejsceZgonuId=").append(miejsceZgonuId);
        sb.append(", odpowiedzialnyZaPogrzebId=").append(odpowiedzialnyZaPogrzebId);
        sb.append(", godzina=").append(godzina);
        sb.append(", miejscePochowku=").append(miejscePochowku);
        sb.append(", nrAktZgon=").append(nrAktZgon);
        sb.append(", status=").append(status);
        sb.append(", uwagi=").append(uwagi);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append("]");
        return sb.toString();
    }
}
